@@ -1,5 +1,5 @@
-from typing import Optional
 from .rustws import RustWsClient
+from .event_handler import EventHandler
 from .token_bucket import RateLimiter
 from ...commands import CommandHandler
 from ...exceptions import ClientNotConnectedError
@@ -22,6 +22,8 @@ class RustRemote:
             self.command_options = command_options
             self.command_handler = CommandHandler(self.command_options)
 
+        self.event_handler = EventHandler()
+
     def connect(self) -> None:
 
         self.ws = RustWsClient(ip=self.ip, port=self.port, remote=self, protocols=['http-only', 'chat'])
